@@ -15,7 +15,7 @@ DEFAULT_CONFIG = {
                 {"color": []},
                 {"background": []},
             ],
-            ["code-block", "link", "image"],
+            ["code-block", "link", "image", "video"],
             ["clean"],
         ],
         # quill-image-compress
@@ -34,7 +34,7 @@ DEFAULT_CONFIG = {
 MEDIA_JS = [
     "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/10.1.1/highlight.min.js",
     "https://cdn.quilljs.com/1.3.7/quill.min.js",
-    "https://unpkg.com/lhy-quill-image-compress@1.2.5/dist/quill.imageCompressor.min.js",
+    "https://unpkg.com/quill-image-compress@1.2.21/dist/quill.imageCompressor.min.js",
     "https://cdn.jsdelivr.net/npm/quill-image-resize-module@3.0.0/image-resize.min.js",
     "django_quill/django_quill.js",
 ]
