@@ -3,3 +3,6 @@ from django.apps import AppConfig
 
 class PostsConfig(AppConfig):
     name = "posts"
+
+    def ready(self):
+        import posts.signals
